/*
 * Copyright (c) 2006 Mysema Ltd.
 * All rights reserved.
 * 
 */
package com.mysema.l10n;

import java.util.Locale;

import org.apache.commons.lang.StringUtils;

/**
 * States provides
 * 
 * @author Samppa Saarela
 * @version $Id: States.java 2785 2007-10-23 16:17:35Z tiwe $
 */
public enum States implements State {

    LCV {
        public boolean apply(Locale l, StringBuilder baseName) {
            if (StringUtils.isBlank(l.getLanguage()) 
                    || StringUtils.isBlank(l.getCountry())
                    || StringUtils.isBlank(l.getVariant())) {
                return false;
            }
            baseName.append("_")
            .append(l.getLanguage())
            .append("_")
            .append(l.getCountry())
            .append("_")
            .append(l.getVariant());
            return true;
        }
    },

    LV {
        public boolean apply(Locale l, StringBuilder baseName) {
            if (StringUtils.isBlank(l.getLanguage()) 
                    || StringUtils.isBlank(l.getVariant())) {
                return false;
            }
            baseName.append("_")
            .append(l.getLanguage())
            .append("__")
            .append(l.getVariant());
            return true;
        }
    },

    V {
        public boolean apply(Locale l, StringBuilder baseName) {
            if (StringUtils.isBlank(l.getVariant())) {
                return false;
            }
            baseName.append("___")
            .append(l.getVariant());
            return true;
        }
    },

    LC {
        public boolean apply(Locale l, StringBuilder baseName) {
            if (StringUtils.isBlank(l.getLanguage()) 
                    || StringUtils.isBlank(l.getCountry())) {
                return false;
            }
            baseName.append("_")
            .append(l.getLanguage())
            .append("_")
            .append(l.getCountry());
            return true;
        }
    },

    L {
        public boolean apply(Locale l, StringBuilder baseName) {
            if (StringUtils.isBlank(l.getLanguage())) {
                return false;
            }
            baseName.append("_")
            .append(l.getLanguage());
            return true;
        }
    },

    C {
        public boolean apply(Locale l, StringBuilder baseName) {
            if (StringUtils.isBlank(l.getCountry())) {
                return false;
            }
            baseName.append("__")
            .append(l.getCountry());
            return true;
        }
    },

    DEFAULT {
        public boolean apply(Locale l, StringBuilder baseName) {
            return false;
        }
        
        public Locale convert(Locale l) {
            return Locale.getDefault();
        }
        
        public Locale filter(Locale l) {
            return Locale.getDefault();
        }
    },

    BARE {
        public boolean apply(Locale l, StringBuilder baseName) {
            return true;
        }

        public Locale filter(Locale l) {
            return new Locale("");
        }
    };
    
    public abstract boolean apply(Locale l, StringBuilder baseName);
    
    public Locale convert(Locale l) {
        return l;
    }
    
    public Locale filter(Locale l) {
        String def = toString();
        if (def.length() < 4) {
            return new Locale(
                    def.indexOf('L') >= 0 ? l.getLanguage() : "", 
                    def.indexOf('C') >= 0 ? l.getCountry() : "", 
                    def.indexOf('V') >= 0 ? l.getVariant() : "" 
            );
        } else {
            return null;
        }
    }

}
