/*
 * Copyright (c) 2006 Mysema Ltd.
 * All rights reserved.
 * 
 */
package com.mysema.l10n.support;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Locale;
import java.util.Map;
import java.util.Set;

import com.mysema.l10n.IllegalLocaleException;


/**
 * LocaleUtil provides
 * 
 * @author Samppa Saarela
 * @version $Id: LocaleUtil.java 2773 2007-09-21 16:15:36Z tiwe $
 */
public final class LocaleUtil {

    public static final Locale BASE_LOCALE = new Locale("");

    /**
     * @param locale
     * @return
     */
    public static Locale parseLocale(String locale) {
        if (locale == null) {
            return BASE_LOCALE;
        }
        String[] s = locale.split("[_-]", 3);
        switch (s.length) {
        case 0:
            return BASE_LOCALE;
        case 1:
            return new Locale(s[0]);
        case 2:
            return new Locale(s[0], s[1]);
        case 3:
            return new Locale(s[0], s[1], s[2]);
        default:
            throw new IllegalLocaleException(locale);
        }
    }
    
    /**
     * @param strings
     * @param locale
     * @return
     */
    public static <Value>Value getLocalized(Map<Locale,Value> values, Locale locale,
            Value defaultValue) {
        Value rv = null;

        if (values != null && values.size() > 0) {
            // Use locale search path to find the best matching string
            for (Iterator i = new LocaleIterator(locale, true); rv == null
                    && i.hasNext();) {
                rv = values.get(i.next());
            }

            // ...or if no match is found, pick any string
            if (rv == null && !values.isEmpty()) {
                rv = (values.entrySet().iterator().next()).getValue();
            }
        }
        // ...if rv is still null, use defaultValue
        if (rv == null) {
            rv = defaultValue;
        }
        return rv;
    }

    /**
     * @param string
     * @return
     */
    public static Map<Locale, String> parseLiterals(String string) {
        // fi: Suomeksi; en_GB: In english; : default
        Map<Locale, String> rv = new HashMap<Locale, String>();
        String[] literals = string.split(";");
        for (int i = 0; i < literals.length; i++) {
            String[] lsplit = literals[i].split(":", 2);
            if (lsplit.length == 2) {
                rv.put(parseLocale(lsplit[0].trim()), lsplit[1].trim());
            }
        }
        return rv;
    }

    public static String encodeLiterals(Map<Locale, String> literals) {
        Set<Map.Entry<Locale, String>> entries = literals.entrySet();
        StringBuilder sb = new StringBuilder(entries.size() * 10);
        for (Map.Entry<Locale,String> entry : entries) {
            if (sb.length() > 0) {
                sb.append("; ");
            }
            sb.append(entry.getKey());
            sb.append(": ");
            sb.append(entry.getValue());
        }
        return sb.toString();
    }
}
